# Python scripts

Set of python scripts to show how to implement the `biobroker` library into your own scripts/services. Currently
containts:

## Biosamples
- Full example, with set-up, submission, retrieval, update.